@@ -474,7 +474,7 @@ class TrainLoop:
         self.train_history.insert_single_result_into_history(metric_name, metric_result)
 
     def fit_distributed(self, num_epochs, callbacks=None, grad_accumulation=1,
-                        train_data_shuffle=True, ddp_model_args=None, in_process_data_load=None,
+                        ddp_model_args=None, in_process_data_load=None,
                         num_nodes=1, node_rank=0, num_gpus=torch.cuda.device_count()):
         """Train the model using the train loop in the Distributed Data Parallel setting
 
@@ -484,7 +484,6 @@ class TrainLoop:
             num_epochs (int): how many epochs the network will be trained
             callbacks (list or None): callbacks that are executed during the training run
             grad_accumulation (int): number of batches the gradients are accumulated before updating weights
-            train_data_shuffle (bool): should train loader return shuffled data
             ddp_model_args (dict or None): parameters for DistributedDataParallel / APEX DistributedDataParallel model
                 Available parameters for DistributedDataParallel:
                     https://pytorch.org/docs/master/nn.html#torch.nn.parallel.DistributedDataParallel
@@ -506,7 +505,6 @@ class TrainLoop:
             'node_rank': node_rank,
             'num_gpus': num_gpus,
             'world_size': num_nodes * num_gpus,
-            'train_data_shuffle': train_data_shuffle,
             'ddp_model_args': ddp_model_args if ddp_model_args is not None else {}
         }
 
@@ -546,7 +544,7 @@ class TrainLoop:
         self.callbacks_handler.execute_multiprocess_start()
         # Add DistributedSampler to the data loaders
         self.ddp_handler = DDPHandler(self)
-        self.ddp_handler.add_distributed_samplers(ddp_args['world_size'], rank, ddp_args['train_data_shuffle'])
+        self.ddp_handler.add_distributed_samplers(ddp_args['world_size'], rank)
 
         # Move to the GPU belonging to the process
         self.model = self.model.to(self.device)
@@ -572,25 +570,31 @@ class TrainLoop:
 
         self.fit(num_epochs, callbacks, grad_accumulation)
 
-    def fit_data_parallel(self, num_epochs, callbacks=None, dp_wrap_attributes=None):
+    def fit_data_parallel(self, num_epochs, callbacks=None, grad_accumulation=1, dp_model_args=None):
         """Train the model on multi-GPU with DataParallel auto wrapping
 
         Args:
             num_epochs (int): how many epochs the network will be trained
             callbacks (list or None): callbacks that are executed during the training run
-            dp_wrap_attributes (list or tuple or None): additional TTModel attributes which need to be transferred to
-                the TTDataParallel level to enable their use in the transferred/exposed class methods
+            grad_accumulation (int): number of batches the gradients are accumulated before updating weights
+            dp_model_args (dict or None): parameters for :class:`aitoolbox.torchtrain.parallel.TTDataParallel` /
+                ``nn.DataParallel`` DP model wrap.
+                Probably the most common optional parameter to set is ``TTDataParallel``'s ``add_model_attributes``
+                list. In this list the user can list any additional TTModel attributes which need to be transferred to
+                the TTDataParallel level to enable their use in the transferred/exposed class methods.
 
         Returns:
-            TTDataParallel: trained model
+            TTDataParallel or nn.DataParallel: trained model
         """
+        dp_model_args = dp_model_args if dp_model_args is not None else {}
+
         if not isinstance(self.model, TTDataParallel) and not isinstance(self.model, nn.DataParallel):
             if isinstance(self.model, TTModel):
-                self.model = TTDataParallel(self.model, dp_wrap_attributes)
+                self.model = TTDataParallel(self.model, **dp_model_args)
             else:
-                self.model = nn.DataParallel(self.model)
+                self.model = nn.DataParallel(self.model, **dp_model_args)
 
-        return self.fit(num_epochs, callbacks)
+        return self.fit(num_epochs, callbacks, grad_accumulation)
 
     def fit_deepspeed(self, deepspeed_args, num_epochs, callbacks=None,
                       add_model_attributes=None, **ds_model_args):
@@ -757,10 +761,10 @@ class TrainLoopEndSave(TrainLoop):
                 ensure the python experiment file copying to the experiment folder, the user needs to manually
                 specify the python file path as the value for the `experiment_file_path` key. If running the training
                 directly from the terminal the path deduction is done automatically.
-            val_result_package (aitoolbox.experiment.result_package.abstract_result_packages.AbstractResultPackage or None):
-                result package evaluated on validation data at the end of training
-            test_result_package (aitoolbox.experiment.result_package.abstract_result_packages.AbstractResultPackage or None):
-                result package evaluated on test data at the end of training
+            val_result_package (AbstractResultPackage or None): result package evaluated on validation data at  the end
+                of the training
+            test_result_package (AbstractResultPackage or None): result package evaluated on test data at the end
+                of the training
             cloud_save_mode (str or None): Storage destination selector.
                 For AWS S3: 's3' / 'aws_s3' / 'aws'
                 For Google Cloud Storage: 'gcs' / 'google_storage' / 'google storage'
@@ -859,10 +863,10 @@ class TrainLoopCheckpointEndSave(TrainLoopEndSave):
                 ensure the python experiment file copying to the experiment folder, the user needs to manually
                 specify the python file path as the value for the `experiment_file_path` key. If running the training
                 directly from the terminal the path deduction is done automatically.
-            val_result_package (aitoolbox.experiment.result_package.abstract_result_packages.AbstractResultPackage or None):
-                result package evaluated on validation data at the end of training
-            test_result_package (aitoolbox.experiment.result_package.abstract_result_packages.AbstractResultPackage or None):
-                result package evaluated on test data at the end of training
+            val_result_package (AbstractResultPackage or None): result package evaluated on validation data at the end
+                of the training
+            test_result_package (AbstractResultPackage or None): result package evaluated on test data at the end
+                of the training
             cloud_save_mode (str or None): Storage destination selector.
                 For AWS S3: 's3' / 'aws_s3' / 'aws'
                 For Google Cloud Storage: 'gcs' / 'google_storage' / 'google storage'
